@@ -11,10 +11,10 @@ import (
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/archive"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -76,14 +76,18 @@ func TestRunPipe(t *testing.T) {
 			f, err := os.Create(filepath.Join(filepath.Join(folder, "foo", "bar", "foobar", "blah.txt")))
 			require.NoError(t, err)
 			require.NoError(t, f.Close())
-			ctx := context.New(
+			ctx := testctx.NewWithCfg(
 				config.Project{
 					Dist:        dist,
 					ProjectName: "foobar",
 					Archives: []config.Archive{
 						{
-							ID:                      "myid",
-							Builds:                  []string{"default"},
+							ID:     "myid",
+							Builds: []string{"default"},
+							BuildsInfo: config.FileInfo{
+								Owner: "root",
+								Group: "root",
+							},
 							NameTemplate:            defaultNameTemplate,
 							StripParentBinaryFolder: dets.Strip,
 							Files: []config.File{
@@ -233,6 +237,11 @@ func TestRunPipe(t *testing.T) {
 						},
 						tarFiles(t, filepath.Join(dist, name)),
 					)
+
+					header := tarInfo(t, filepath.Join(dist, name), expectBin)
+					require.Equal(t, "root", header.Uname)
+					require.Equal(t, "root", header.Gname)
+
 				}
 			}
 			if format == "zip" {
@@ -258,7 +267,7 @@ func TestRunPipeDifferentBinaryCount(t *testing.T) {
 		createFakeBinary(t, dist, arch, "bin/mybin")
 	}
 	createFakeBinary(t, dist, "darwinamd64", "bin/foobar")
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        dist,
 		ProjectName: "foobar",
 		Archives: []config.Archive{
@@ -325,15 +334,13 @@ func TestRunPipeNoBinaries(t *testing.T) {
 	folder := testlib.Mktmp(t)
 	dist := filepath.Join(folder, "dist")
 	require.NoError(t, os.Mkdir(dist, 0o755))
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        dist,
 		ProjectName: "foobar",
 		Archives: []config.Archive{{
 			Builds: []string{"not-default"},
 		}},
-	})
-	ctx.Version = "0.0.1"
-	ctx.Git.CurrentTag = "v0.0.1"
+	}, testctx.WithVersion("0.0.1"), testctx.WithCurrentTag("v1.0.0"))
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "linux",
 		Goarch: "amd64",
@@ -363,6 +370,27 @@ func zipFiles(t *testing.T, path string) []string {
 	return paths
 }
 
+func tarInfo(t *testing.T, path, name string) *tar.Header {
+	t.Helper()
+	f, err := os.Open(path)
+	require.NoError(t, err)
+	defer f.Close()
+	gr, err := gzip.NewReader(f)
+	require.NoError(t, err)
+	defer gr.Close()
+	r := tar.NewReader(gr)
+	for {
+		next, err := r.Next()
+		if err == io.EOF {
+			break
+		}
+		if next.Name == name {
+			return next
+		}
+	}
+	return nil
+}
+
 func tarFiles(t *testing.T, path string) []string {
 	t.Helper()
 	f, err := os.Open(path)
@@ -402,7 +430,7 @@ func TestRunPipeBinary(t *testing.T) {
 	f, err = os.Create(filepath.Join(folder, "README.md"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -413,9 +441,9 @@ func TestRunPipeBinary(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithVersion("0.0.1"),
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Version = "0.0.1"
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "darwin",
 		Goarch: "amd64",
@@ -489,7 +517,7 @@ func TestRunPipeBinary(t *testing.T) {
 }
 
 func TestRunPipeDistRemoved(t *testing.T) {
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: "/tmp/path/to/nope",
 			Archives: []config.Archive{
@@ -500,8 +528,8 @@ func TestRunPipeDistRemoved(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "windows",
 		Goarch: "amd64",
@@ -526,7 +554,7 @@ func TestRunPipeInvalidGlob(t *testing.T) {
 	f, err := os.Create(filepath.Join(dist, "darwinamd64", "mybin"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -540,6 +568,7 @@ func TestRunPipeInvalidGlob(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
 	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
@@ -564,7 +593,7 @@ func TestRunPipeInvalidNameTemplate(t *testing.T) {
 	f, err := os.Create(filepath.Join(dist, "darwinamd64", "mybin"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -575,8 +604,8 @@ func TestRunPipeInvalidNameTemplate(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "darwin",
 		Goarch: "amd64",
@@ -599,7 +628,7 @@ func TestRunPipeInvalidFilesNameTemplate(t *testing.T) {
 	f, err := os.Create(filepath.Join(dist, "darwinamd64", "mybin"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -613,8 +642,8 @@ func TestRunPipeInvalidFilesNameTemplate(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "darwin",
 		Goarch: "amd64",
@@ -637,7 +666,7 @@ func TestRunPipeInvalidWrapInDirectoryTemplate(t *testing.T) {
 	f, err := os.Create(filepath.Join(dist, "darwinamd64", "mybin"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -649,8 +678,8 @@ func TestRunPipeInvalidWrapInDirectoryTemplate(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "darwin",
 		Goarch: "amd64",
@@ -676,7 +705,7 @@ func TestRunPipeWrap(t *testing.T) {
 	f, err = os.Create(filepath.Join(folder, "README.md"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
@@ -694,8 +723,8 @@ func TestRunPipeWrap(t *testing.T) {
 				},
 			},
 		},
+		testctx.WithCurrentTag("v0.0.1"),
 	)
-	ctx.Git.CurrentTag = "v0.0.1"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Goos:   "darwin",
 		Goarch: "amd64",
@@ -732,69 +761,77 @@ func TestRunPipeWrap(t *testing.T) {
 }
 
 func TestDefault(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			Archives: []config.Archive{},
-		},
-	}
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{},
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NotEmpty(t, ctx.Config.Archives[0].NameTemplate)
 	require.Equal(t, "tar.gz", ctx.Config.Archives[0].Format)
 	require.NotEmpty(t, ctx.Config.Archives[0].Files)
+	require.False(t, ctx.Config.Archives[0].RLCP)
 }
 
 func TestDefaultSet(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			Archives: []config.Archive{
-				{
-					Builds:       []string{"default"},
-					NameTemplate: "foo",
-					Format:       "zip",
-					Files: []config.File{
-						{Source: "foo"},
-					},
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Builds:       []string{"default"},
+				NameTemplate: "foo",
+				Format:       "zip",
+				Files: []config.File{
+					{Source: "foo"},
 				},
 			},
 		},
-	}
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "foo", ctx.Config.Archives[0].NameTemplate)
 	require.Equal(t, "zip", ctx.Config.Archives[0].Format)
+	require.False(t, ctx.Config.Archives[0].RLCP)
 	require.Equal(t, config.File{Source: "foo"}, ctx.Config.Archives[0].Files[0])
 }
 
-func TestDefaultFormatBinary(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			Archives: []config.Archive{
-				{
-					Format: "binary",
-				},
+func TestDefaultNoFiles(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Format: "tar.gz",
 			},
 		},
-	}
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.Equal(t, defaultNameTemplate, ctx.Config.Archives[0].NameTemplate)
+	require.False(t, ctx.Config.Archives[0].RLCP)
+}
+
+func TestDefaultFormatBinary(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Format: "binary",
+			},
+		},
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, defaultBinaryNameTemplate, ctx.Config.Archives[0].NameTemplate)
+	require.False(t, ctx.Config.Archives[0].RLCP)
 }
 
 func TestFormatFor(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			Archives: []config.Archive{
-				{
-					Builds: []string{"default"},
-					Format: "tar.gz",
-					FormatOverrides: []config.FormatOverride{
-						{
-							Goos:   "windows",
-							Format: "zip",
-						},
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				Builds: []string{"default"},
+				Format: "tar.gz",
+				FormatOverrides: []config.FormatOverride{
+					{
+						Goos:   "windows",
+						Format: "zip",
 					},
 				},
 			},
 		},
-	}
+	})
 	require.Equal(t, "zip", packageFormat(ctx.Config.Archives[0], "windows"))
 	require.Equal(t, "tar.gz", packageFormat(ctx.Config.Archives[0], "linux"))
 }
@@ -816,7 +853,7 @@ func TestBinaryOverride(t *testing.T) {
 	require.NoError(t, f.Close())
 	for _, format := range []string{"tar.gz", "zip"} {
 		t.Run("Archive format "+format, func(t *testing.T) {
-			ctx := context.New(
+			ctx := testctx.NewWithCfg(
 				config.Project{
 					Dist:        dist,
 					ProjectName: "foobar",
@@ -836,8 +873,8 @@ func TestBinaryOverride(t *testing.T) {
 						},
 					},
 				},
+				testctx.WithCurrentTag("v0.0.1"),
 			)
-			ctx.Git.CurrentTag = "v0.0.1"
 			ctx.Artifacts.Add(&artifact.Artifact{
 				Goos:   "darwin",
 				Goarch: "amd64",
@@ -892,7 +929,7 @@ func TestRunPipeSameArchiveFilename(t *testing.T) {
 	f, err = os.Create(filepath.Join(dist, "windowsamd64", "mybin.exe"))
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(
+	ctx := testctx.NewWithCfg(
 		config.Project{
 			Dist:        dist,
 			ProjectName: "foobar",
@@ -988,18 +1025,16 @@ func TestWrapInDirectory(t *testing.T) {
 }
 
 func TestSeveralArchivesWithTheSameID(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			Archives: []config.Archive{
-				{
-					ID: "a",
-				},
-				{
-					ID: "a",
-				},
+	ctx := testctx.NewWithCfg(config.Project{
+		Archives: []config.Archive{
+			{
+				ID: "a",
+			},
+			{
+				ID: "a",
 			},
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Default(ctx), "found 2 archives with the ID 'a', please fix your config")
 }
 
@@ -1009,7 +1044,7 @@ func TestArchive_globbing(t *testing.T) {
 		bin, err := os.CreateTemp(t.TempDir(), "binary")
 		require.NoError(t, err)
 		dist := t.TempDir()
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Dist: dist,
 			Archives: []config.Archive{
 				{
@@ -1087,7 +1122,7 @@ func TestArchive_globbing(t *testing.T) {
 }
 
 func TestInvalidFormat(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist: t.TempDir(),
 		Archives: []config.Archive{
 			{
@@ -1100,3 +1135,32 @@ func TestInvalidFormat(t *testing.T) {
 	})
 	require.EqualError(t, Pipe{}.Run(ctx), "invalid archive format: 7z")
 }
+
+func TestIssue3803(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Dist: t.TempDir(),
+		Archives: []config.Archive{
+			{
+				ID:           "foo",
+				NameTemplate: "foo",
+				Meta:         true,
+				Format:       "zip",
+				Files: []config.File{
+					{Source: "./testdata/a/a.txt"},
+				},
+			},
+			{
+				ID:           "foobar",
+				NameTemplate: "foobar",
+				Meta:         true,
+				Format:       "zip",
+				Files: []config.File{
+					{Source: "./testdata/a/b/a.txt"},
+				},
+			},
+		},
+	})
+	require.NoError(t, Pipe{}.Run(ctx))
+	archives := ctx.Artifacts.List()
+	require.Len(t, archives, 2)
+}
