@@ -9,6 +9,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -106,7 +107,7 @@ func TestFullFormulae(t *testing.T) {
 	data.PostInstall = []string{`touch "/tmp/foo"`, `system "echo", "done"`}
 	data.CustomBlock = []string{"devel do", `  url "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz"`, `  sha256 "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68"`, "end"}
 	data.Tests = []string{`system "#{bin}/{{.ProjectName}}", "-version"`}
-	formulae, err := doBuildFormula(context.New(config.Project{
+	formulae, err := doBuildFormula(testctx.NewWithCfg(config.Project{
 		ProjectName: "foo",
 	}), data)
 	require.NoError(t, err)
@@ -117,7 +118,7 @@ func TestFullFormulae(t *testing.T) {
 func TestFullFormulaeLinuxOnly(t *testing.T) {
 	data := defaultTemplateData
 	data.MacOSPackages = []releasePackage{}
-	formulae, err := doBuildFormula(context.New(config.Project{
+	formulae, err := doBuildFormula(testctx.NewWithCfg(config.Project{
 		ProjectName: "foo",
 	}), data)
 	require.NoError(t, err)
@@ -128,7 +129,7 @@ func TestFullFormulaeLinuxOnly(t *testing.T) {
 func TestFullFormulaeMacOSOnly(t *testing.T) {
 	data := defaultTemplateData
 	data.LinuxPackages = []releasePackage{}
-	formulae, err := doBuildFormula(context.New(config.Project{
+	formulae, err := doBuildFormula(testctx.NewWithCfg(config.Project{
 		ProjectName: "foo",
 	}), data)
 	require.NoError(t, err)
@@ -137,7 +138,7 @@ func TestFullFormulaeMacOSOnly(t *testing.T) {
 }
 
 func TestFormulaeSimple(t *testing.T) {
-	formulae, err := doBuildFormula(context.New(config.Project{}), defaultTemplateData)
+	formulae, err := doBuildFormula(testctx.NewWithCfg(config.Project{}), defaultTemplateData)
 	require.NoError(t, err)
 	assertDefaultTemplateData(t, formulae)
 	require.NotContains(t, formulae, "def caveats")
@@ -258,16 +259,8 @@ func TestFullPipe(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
-			ctx := &context.Context{
-				Git: context.GitInfo{
-					CurrentTag: "v1.0.1",
-				},
-				Version:   "1.0.1",
-				Artifacts: artifact.New(),
-				Env: map[string]string{
-					"FOO": "foo_is_bar",
-				},
-				Config: config.Project{
+			ctx := testctx.NewWithCfg(
+				config.Project{
 					Dist:        folder,
 					ProjectName: name,
 					Brews: []config.Homebrew{
@@ -292,8 +285,11 @@ func TestFullPipe(t *testing.T) {
 							Goamd64:     "v1",
 						},
 					},
+					Env: []string{"FOO=foo_is_bar"},
 				},
-			}
+				testctx.WithVersion("1.0.1"),
+				testctx.WithCurrentTag("v1.0.1"),
+			)
 			tt.prepare(ctx)
 			ctx.Artifacts.Add(&artifact.Artifact{
 				Name:    "bar_bin.tar.gz",
@@ -374,16 +370,8 @@ func TestFullPipe(t *testing.T) {
 
 func TestRunPipeNameTemplate(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Env: map[string]string{
-			"FOO_BAR": "is_bar",
-		},
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			Brews: []config.Homebrew{
@@ -402,8 +390,11 @@ func TestRunPipeNameTemplate(t *testing.T) {
 					},
 				},
 			},
+			Env: []string{"FOO_BAR=is_bar"},
 		},
-	}
+		testctx.WithVersion("1.0.1"),
+		testctx.WithCurrentTag("v1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin.tar.gz",
@@ -435,17 +426,8 @@ func TestRunPipeNameTemplate(t *testing.T) {
 
 func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Env: map[string]string{
-			"FOO_BAR":     "is_bar",
-			"SKIP_UPLOAD": "true",
-		},
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			Brews: []config.Homebrew{
@@ -497,8 +479,14 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 					SkipUpload: "{{ .Env.SKIP_UPLOAD }}",
 				},
 			},
+			Env: []string{
+				"FOO_BAR=is_bar",
+				"SKIP_UPLOAD=true",
+			},
 		},
-	}
+		testctx.WithVersion("1.0.1"),
+		testctx.WithCurrentTag("v1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin.tar.gz",
@@ -546,17 +534,8 @@ func TestRunPipeForMultipleAmd64Versions(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
-			ctx := &context.Context{
-				TokenType: context.TokenTypeGitHub,
-				Git: context.GitInfo{
-					CurrentTag: "v1.0.1",
-				},
-				Version:   "1.0.1",
-				Artifacts: artifact.New(),
-				Env: map[string]string{
-					"FOO": "foo_is_bar",
-				},
-				Config: config.Project{
+			ctx := testctx.NewWithCfg(
+				config.Project{
 					Dist:        folder,
 					ProjectName: name,
 					Brews: []config.Homebrew{
@@ -580,8 +559,12 @@ func TestRunPipeForMultipleAmd64Versions(t *testing.T) {
 							Name:  "test",
 						},
 					},
+					Env: []string{"FOO=foo_is_bar"},
 				},
-			}
+				testctx.GitHubTokenType,
+				testctx.WithVersion("1.0.1"),
+				testctx.WithCurrentTag("v1.0.1"),
+			)
 			fn(ctx)
 			for _, a := range []struct {
 				name    string
@@ -671,17 +654,8 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
-			ctx := &context.Context{
-				TokenType: context.TokenTypeGitHub,
-				Git: context.GitInfo{
-					CurrentTag: "v1.0.1",
-				},
-				Version:   "1.0.1",
-				Artifacts: artifact.New(),
-				Env: map[string]string{
-					"FOO": "foo_is_bar",
-				},
-				Config: config.Project{
+			ctx := testctx.NewWithCfg(
+				config.Project{
 					Dist:        folder,
 					ProjectName: name,
 					Brews: []config.Homebrew{
@@ -710,8 +684,12 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 							Name:  "test",
 						},
 					},
+					Env: []string{"FOO=foo_is_bar"},
 				},
-			}
+				testctx.GitHubTokenType,
+				testctx.WithVersion("1.0.1"),
+				testctx.WithCurrentTag("v1.0.1"),
+			)
 			fn(ctx)
 			for _, a := range []struct {
 				name   string
@@ -782,39 +760,33 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 }
 
 func TestRunPipeNoBuilds(t *testing.T) {
-	ctx := context.New(
-		config.Project{
-			Brews: []config.Homebrew{
-				{
-					Tap: config.RepoRef{
-						Owner: "test",
-						Name:  "test",
-					},
+	ctx := testctx.NewWithCfg(config.Project{
+		Brews: []config.Homebrew{
+			{
+				Tap: config.RepoRef{
+					Owner: "test",
+					Name:  "test",
 				},
 			},
 		},
-	)
-	ctx.TokenType = context.TokenTypeGitHub
+	}, testctx.GitHubTokenType)
 	client := client.NewMock()
 	require.Equal(t, ErrNoArchivesFound, runAll(ctx, client))
 	require.False(t, client.CreatedFile)
 }
 
 func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
-	ctx := context.New(
-		config.Project{
-			Brews: []config.Homebrew{
-				{
-					Tap: config.RepoRef{
-						Owner: "test",
-						Name:  "test",
-					},
+	ctx := testctx.NewWithCfg(config.Project{
+		Brews: []config.Homebrew{
+			{
+				Tap: config.RepoRef{
+					Owner: "test",
+					Name:  "test",
 				},
 			},
 		},
-	)
+	}, testctx.GitHubTokenType)
 
-	ctx.TokenType = context.TokenTypeGitHub
 	f, err := os.CreateTemp(t.TempDir(), "")
 	require.NoError(t, err)
 	t.Cleanup(func() {
@@ -949,13 +921,8 @@ func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
 
 func TestRunPipeBinaryRelease(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.2.1",
-		},
-		Version:   "1.2.1",
-		Artifacts: artifact.New(),
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			Brews: []config.Homebrew{
@@ -970,8 +937,9 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 				},
 			},
 		},
-	}
-
+		testctx.WithVersion("1.2.1"),
+		testctx.WithCurrentTag("v1.2.1"),
+	)
 	path := filepath.Join(folder, "dist/foo_darwin_all/foo")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "foo_macos",
@@ -1000,7 +968,7 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 
 func TestRunPipeNoUpload(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        folder,
 		ProjectName: "foo",
 		Release:     config.Release{},
@@ -1013,12 +981,8 @@ func TestRunPipeNoUpload(t *testing.T) {
 				Goamd64: "v1",
 			},
 		},
-	})
-	ctx.Env = map[string]string{
-		"SKIP_UPLOAD": "true",
-	}
-	ctx.TokenType = context.TokenTypeGitHub
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
+		Env: []string{"SKIP_UPLOAD=true"},
+	}, testctx.WithCurrentTag("v1.0.1"), testctx.GitHubTokenType)
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -1062,7 +1026,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 
 func TestRunEmptyTokenType(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        folder,
 		ProjectName: "foo",
 		Release:     config.Release{},
@@ -1075,8 +1039,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 				Goamd64: "v1",
 			},
 		},
-	})
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
+	}, testctx.WithCurrentTag("v1.0.0"))
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -1099,16 +1062,12 @@ func TestRunEmptyTokenType(t *testing.T) {
 
 func TestDefault(t *testing.T) {
 	testlib.Mktmp(t)
-
-	ctx := &context.Context{
-		TokenType: context.TokenTypeGitHub,
-		Config: config.Project{
-			ProjectName: "myproject",
-			Brews: []config.Homebrew{
-				{},
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "myproject",
+		Brews: []config.Homebrew{
+			{},
 		},
-	}
+	}, testctx.GitHubTokenType)
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ctx.Config.ProjectName, ctx.Config.Brews[0].Name)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Name)
@@ -1123,11 +1082,11 @@ func TestGHFolder(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Brews: []config.Homebrew{
 				{},
 			},
@@ -1137,7 +1096,7 @@ func TestSkip(t *testing.T) {
 }
 
 func TestRunSkipNoName(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Brews: []config.Homebrew{{}},
 	})
 
@@ -1148,7 +1107,7 @@ func TestRunSkipNoName(t *testing.T) {
 func TestInstalls(t *testing.T) {
 	t.Run("provided", func(t *testing.T) {
 		install, err := installs(
-			context.New(config.Project{}),
+			testctx.New(),
 			config.Homebrew{Install: "bin.install \"foo\"\nbin.install \"bar\""},
 			&artifact.Artifact{},
 		)
@@ -1161,8 +1120,7 @@ func TestInstalls(t *testing.T) {
 
 	t.Run("from archives", func(t *testing.T) {
 		install, err := installs(
-			context.New(config.Project{}),
-
+			testctx.New(),
 			config.Homebrew{},
 			&artifact.Artifact{
 				Type: artifact.UploadableArchive,
@@ -1180,7 +1138,7 @@ func TestInstalls(t *testing.T) {
 
 	t.Run("from binary", func(t *testing.T) {
 		install, err := installs(
-			context.New(config.Project{}),
+			testctx.New(),
 			config.Homebrew{},
 			&artifact.Artifact{
 				Name: "foo_macos",
@@ -1198,7 +1156,7 @@ func TestInstalls(t *testing.T) {
 
 	t.Run("from template", func(t *testing.T) {
 		install, err := installs(
-			context.New(config.Project{}),
+			testctx.New(),
 			config.Homebrew{
 				Install: `bin.install "foo_{{.Os}}" => "foo"`,
 			},
@@ -1217,13 +1175,8 @@ func TestInstalls(t *testing.T) {
 
 func TestRunPipeUniversalBinary(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "unibin",
 			Brews: []config.Homebrew{
@@ -1242,7 +1195,9 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 				},
 			},
 		},
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "bin.tar.gz",
@@ -1275,13 +1230,8 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 
 func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "unibin",
 			Brews: []config.Homebrew{
@@ -1301,7 +1251,10 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 				},
 			},
 		},
-	}
+
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin_amd64.tar.gz",
