@@ -6,6 +6,7 @@ import (
 
 	_ "github.com/distribution/distribution/v3/registry/auth/htpasswd"
 	_ "github.com/distribution/distribution/v3/registry/storage/driver/inmemory"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -18,7 +19,7 @@ const (
 )
 
 func TestDefault(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Env: []string{
 			"KO_DOCKER_REPO=" + registry,
 			"COSIGN_REPOSITORY=" + registry,
@@ -44,23 +45,22 @@ func TestDefault(t *testing.T) {
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, config.Ko{
-		ID:                "test",
-		Build:             "test",
-		BaseImage:         chainguardStatic,
-		Repository:        registry,
-		RepositoryFromEnv: true,
-		Platforms:         []string{"linux/amd64"},
-		SBOM:              "spdx",
-		Tags:              []string{"latest"},
-		WorkingDir:        ".",
-		Ldflags:           []string{"{{.Env.LDFLAGS}}"},
-		Flags:             []string{"{{.Env.FLAGS}}"},
-		Env:               []string{"SOME_ENV={{.Env.LE_ENV}}"},
+		ID:         "test",
+		Build:      "test",
+		BaseImage:  chainguardStatic,
+		Repository: registry,
+		Platforms:  []string{"linux/amd64"},
+		SBOM:       "spdx",
+		Tags:       []string{"latest"},
+		WorkingDir: ".",
+		Ldflags:    []string{"{{.Env.LDFLAGS}}"},
+		Flags:      []string{"{{.Env.FLAGS}}"},
+		Env:        []string{"SOME_ENV={{.Env.LE_ENV}}"},
 	}, ctx.Config.Kos[0])
 }
 
 func TestDefaultNoImage(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "test",
 		Builds: []config.Build{
 			{
@@ -80,18 +80,18 @@ func TestDescription(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip ko set", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Kos: []config.Ko{{}},
 		})
 		ctx.SkipKo = true
 		require.True(t, Pipe{}.Skip(ctx))
 	})
 	t.Run("skip no kos", func(t *testing.T) {
-		ctx := context.New(config.Project{})
+		ctx := testctx.New()
 		require.True(t, Pipe{}.Skip(ctx))
 	})
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Kos: []config.Ko{{}},
 		})
 		require.False(t, Pipe{}.Skip(ctx))
@@ -99,7 +99,7 @@ func TestSkip(t *testing.T) {
 }
 
 func TestPublishPipeNoMatchingBuild(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Builds: []config.Build{
 			{
 				ID: "doesnt matter",
@@ -153,7 +153,7 @@ func TestPublishPipeSuccess(t *testing.T) {
 
 	for _, table := range table {
 		t.Run(table.Name, func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Builds: []config.Build{
 					{
 						ID: "foo",
@@ -186,7 +186,7 @@ func TestPublishPipeSuccess(t *testing.T) {
 
 func TestPublishPipeError(t *testing.T) {
 	makeCtx := func() *context.Context {
-		ctx := context.New(config.Project{
+		return testctx.NewWithCfg(config.Project{
 			Builds: []config.Build{
 				{
 					ID:   "foo",
@@ -202,9 +202,7 @@ func TestPublishPipeError(t *testing.T) {
 					Tags:       []string{"latest", "{{.Tag}}"},
 				},
 			},
-		})
-		ctx.Git.CurrentTag = "v1.0.0"
-		return ctx
+		}, testctx.WithCurrentTag("v1.0.0"))
 	}
 
 	t.Run("invalid base image", func(t *testing.T) {
@@ -267,14 +265,14 @@ func TestPublishPipeError(t *testing.T) {
 
 func TestApplyTemplate(t *testing.T) {
 	t.Run("success", func(t *testing.T) {
-		foo, err := applyTemplate(context.New(config.Project{
+		foo, err := applyTemplate(testctx.NewWithCfg(config.Project{
 			Env: []string{"FOO=bar"},
 		}), []string{"{{ .Env.FOO }}"})
 		require.NoError(t, err)
 		require.Equal(t, []string{"bar"}, foo)
 	})
 	t.Run("error", func(t *testing.T) {
-		_, err := applyTemplate(context.New(config.Project{}), []string{"{{ .Nope}}"})
+		_, err := applyTemplate(testctx.New(), []string{"{{ .Nope}}"})
 		require.Error(t, err)
 	})
 }
