@@ -12,6 +12,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -218,17 +219,9 @@ func TestFullPipe(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
-			ctx := &context.Context{
-				Git: context.GitInfo{
-					CurrentTag: "v1.0.1",
-				},
-				Version:   "1.0.1",
-				Artifacts: artifact.New(),
-				Env: map[string]string{
-					"FOO": "foo_is_bar",
-					"BAR": "honk",
-				},
-				Config: config.Project{
+
+			ctx := testctx.NewWithCfg(
+				config.Project{
 					Dist:        folder,
 					ProjectName: name,
 					Krews: []config.Krew{
@@ -239,8 +232,11 @@ func TestFullPipe(t *testing.T) {
 							ShortDescription: "short desc {{.Env.BAR}}",
 						},
 					},
+					Env: []string{"FOO=foo_is_bar", "BAR=honk"},
 				},
-			}
+				testctx.WithCurrentTag("v1.0.1"),
+				testctx.WithVersion("1.0.1"),
+			)
 			tt.prepare(ctx)
 			ctx.Artifacts.Add(&artifact.Artifact{
 				Name:    "bar_bin.tar.gz",
@@ -316,13 +312,9 @@ func TestFullPipe(t *testing.T) {
 
 func TestRunPipeUniversalBinary(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Config: config.Project{
+
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "unibin",
 			Krews: []config.Krew{
@@ -340,7 +332,10 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 				},
 			},
 		},
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
+
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "unibin.tar.gz",
@@ -374,13 +369,8 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 
 func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "unibin",
 			Krews: []config.Krew{
@@ -398,7 +388,9 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 				},
 			},
 		},
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "unibin_amd64.tar.gz",
@@ -459,16 +451,8 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 
 func TestRunPipeNameTemplate(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Env: map[string]string{
-			"FOO_BAR": t.Name(),
-		},
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			Krews: []config.Krew{
@@ -485,8 +469,11 @@ func TestRunPipeNameTemplate(t *testing.T) {
 					},
 				},
 			},
+			Env: []string{"FOO_BAR=" + t.Name()},
 		},
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin.tar.gz",
@@ -521,16 +508,8 @@ func TestRunPipeNameTemplate(t *testing.T) {
 
 func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 	folder := t.TempDir()
-	ctx := &context.Context{
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.1",
-		},
-		Version:   "1.0.1",
-		Artifacts: artifact.New(),
-		Env: map[string]string{
-			"FOO_BAR": "is_bar",
-		},
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			Dist:        folder,
 			ProjectName: "foo",
 			Krews: []config.Krew{
@@ -573,8 +552,11 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 					SkipUpload: "true",
 				},
 			},
+			Env: []string{"FOO_BAR=is_bar"},
 		},
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	path := filepath.Join(folder, "bin.tar.gz")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin.tar.gz",
@@ -621,17 +603,8 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			folder := t.TempDir()
-			ctx := &context.Context{
-				TokenType: context.TokenTypeGitHub,
-				Git: context.GitInfo{
-					CurrentTag: "v1.0.1",
-				},
-				Version:   "1.0.1",
-				Artifacts: artifact.New(),
-				Env: map[string]string{
-					"FOO": "foo_is_bar",
-				},
-				Config: config.Project{
+			ctx := testctx.NewWithCfg(
+				config.Project{
 					Dist:        folder,
 					ProjectName: name,
 					Krews: []config.Krew{
@@ -655,8 +628,12 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 							Name:  "test",
 						},
 					},
+					Env: []string{"FOO=foo_is_bar"},
 				},
-			}
+				testctx.GitHubTokenType,
+				testctx.WithVersion("1.0.1"),
+				testctx.WithCurrentTag("v1.0.1"),
+			)
 			fn(ctx)
 			for _, a := range []struct {
 				name   string
@@ -731,22 +708,19 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 }
 
 func TestRunPipeNoBuilds(t *testing.T) {
-	ctx := context.New(
-		config.Project{
-			Krews: []config.Krew{
-				{
-					Name:             manifestName(t),
-					Description:      "Some desc",
-					ShortDescription: "Short desc",
-					Index: config.RepoRef{
-						Owner: "test",
-						Name:  "test",
-					},
+	ctx := testctx.NewWithCfg(config.Project{
+		Krews: []config.Krew{
+			{
+				Name:             manifestName(t),
+				Description:      "Some desc",
+				ShortDescription: "Short desc",
+				Index: config.RepoRef{
+					Owner: "test",
+					Name:  "test",
 				},
 			},
 		},
-	)
-	ctx.TokenType = context.TokenTypeGitHub
+	}, testctx.GitHubTokenType)
 	client := client.NewMock()
 	require.Equal(t, ErrNoArchivesFound, runAll(ctx, client))
 	require.False(t, client.CreatedFile)
@@ -754,7 +728,7 @@ func TestRunPipeNoBuilds(t *testing.T) {
 
 func TestRunPipeNoUpload(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        folder,
 		ProjectName: "foo",
 		Release:     config.Release{},
@@ -769,9 +743,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.TokenType = context.TokenTypeGitHub
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
+	}, testctx.GitHubTokenType, testctx.WithCurrentTag("v1.0.1"))
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -812,7 +784,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 
 func TestRunEmptyTokenType(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        folder,
 		ProjectName: "foo",
 		Release:     config.Release{},
@@ -827,8 +799,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
+	}, testctx.WithCurrentTag("v1.0.1"))
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -853,7 +824,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 
 func TestRunMultipleBinaries(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        folder,
 		ProjectName: "foo",
 		Release:     config.Release{},
@@ -868,8 +839,7 @@ func TestRunMultipleBinaries(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
+	}, testctx.WithCurrentTag("v1.0.1"))
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -895,15 +865,12 @@ func TestRunMultipleBinaries(t *testing.T) {
 func TestDefault(t *testing.T) {
 	testlib.Mktmp(t)
 
-	ctx := &context.Context{
-		TokenType: context.TokenTypeGitHub,
-		Config: config.Project{
-			ProjectName: "myproject",
-			Krews: []config.Krew{
-				{},
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "myproject",
+		Krews: []config.Krew{
+			{},
 		},
-	}
+	}, testctx.GitHubTokenType)
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ctx.Config.ProjectName, ctx.Config.Krews[0].Name)
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitAuthor.Name)
@@ -918,11 +885,11 @@ func TestGHFolder(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Krews: []config.Krew{
 				{},
 			},
@@ -932,7 +899,7 @@ func TestSkip(t *testing.T) {
 }
 
 func TestRunSkipNoName(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Krews: []config.Krew{{}},
 	})
 
