@@ -3,10 +3,10 @@ package nfpm
 import (
 	"os"
 	"path/filepath"
-	"runtime"
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -20,24 +20,57 @@ func TestDescription(t *testing.T) {
 }
 
 func TestRunPipeNoFormats(t *testing.T) {
-	ctx := &context.Context{
-		Version: "1.0.0",
-		Git: context.GitInfo{
-			CurrentTag: "v1.0.0",
-		},
-		Config: config.Project{
+	ctx := testctx.NewWithCfg(
+		config.Project{
 			NFPMs: []config.NFPM{
 				{},
 			},
 		},
-		Parallelism: runtime.NumCPU(),
-	}
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithVersion("1.0.1"),
+	)
 	require.NoError(t, Pipe{}.Default(ctx))
 	testlib.AssertSkipped(t, Pipe{}.Run(ctx))
 }
 
+func TestDefaultsDeprecated(t *testing.T) {
+	t.Run("replacements", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			NFPMs: []config.NFPM{
+				{
+					NFPMOverridables: config.NFPMOverridables{
+						Replacements: map[string]string{
+							"linux": "Tux",
+						},
+					},
+				},
+			},
+		})
+		require.NoError(t, Pipe{}.Default(ctx))
+		require.True(t, ctx.Deprecated)
+	})
+
+	t.Run("replacements overrides", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			NFPMs: []config.NFPM{
+				{
+					Overrides: map[string]config.NFPMOverridables{
+						"apk": {
+							Replacements: map[string]string{
+								"linux": "Tux",
+							},
+						},
+					},
+				},
+			},
+		})
+		require.NoError(t, Pipe{}.Default(ctx))
+		require.True(t, ctx.Deprecated)
+	})
+}
+
 func TestRunPipeError(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist: t.TempDir(),
 		NFPMs: []config.NFPM{
 			{
@@ -63,7 +96,7 @@ func TestRunPipeError(t *testing.T) {
 }
 
 func TestRunPipeInvalidFormat(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "nope",
 		NFPMs: []config.NFPM{
 			{
@@ -76,11 +109,7 @@ func TestRunPipeInvalidFormat(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.2.3"
-	ctx.Git = context.GitInfo{
-		CurrentTag: "v1.2.3",
-	}
+	}, testctx.WithVersion("1.2.3"), testctx.WithCurrentTag("v1.2.3"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -107,7 +136,7 @@ func TestRunPipe(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		Env: []string{
@@ -183,9 +212,7 @@ func TestRunPipe(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin", "ios"} {
 		for _, goarch := range []string{"amd64", "386", "arm64", "arm", "mips"} {
 			if goos == "ios" && goarch != "arm64" {
@@ -320,7 +347,7 @@ func TestRunPipeConventionalNameTemplate(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -342,9 +369,7 @@ func TestRunPipeConventionalNameTemplate(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386", "arm64", "arm", "mips"} {
 			switch goarch {
@@ -459,11 +484,8 @@ func TestRunPipeConventionalNameTemplate(t *testing.T) {
 
 func TestInvalidTemplate(t *testing.T) {
 	makeCtx := func() *context.Context {
-		ctx := &context.Context{
-			Version:     "1.2.3",
-			Parallelism: runtime.NumCPU(),
-			Artifacts:   artifact.New(),
-			Config: config.Project{
+		ctx := testctx.NewWithCfg(
+			config.Project{
 				ProjectName: "test",
 				NFPMs: []config.NFPM{
 					{
@@ -472,7 +494,8 @@ func TestInvalidTemplate(t *testing.T) {
 					},
 				},
 			},
-		}
+			testctx.WithVersion("1.2.3"),
+		)
 		ctx.Artifacts.Add(&artifact.Artifact{
 			Name:   "mybin",
 			Goos:   "linux",
@@ -571,27 +594,23 @@ func TestInvalidTemplate(t *testing.T) {
 }
 
 func TestRunPipeInvalidContentsSourceTemplate(t *testing.T) {
-	ctx := &context.Context{
-		Parallelism: runtime.NumCPU(),
-		Artifacts:   artifact.New(),
-		Config: config.Project{
-			NFPMs: []config.NFPM{
-				{
-					NFPMOverridables: config.NFPMOverridables{
-						PackageName: "foo",
-						Contents: []*files.Content{
-							{
-								Source:      "{{.asdsd}",
-								Destination: "testfile",
-							},
+	ctx := testctx.NewWithCfg(config.Project{
+		NFPMs: []config.NFPM{
+			{
+				NFPMOverridables: config.NFPMOverridables{
+					PackageName: "foo",
+					Contents: []*files.Content{
+						{
+							Source:      "{{.asdsd}",
+							Destination: "testfile",
 						},
 					},
-					Formats: []string{"deb"},
-					Builds:  []string{"default"},
 				},
+				Formats: []string{"deb"},
+				Builds:  []string{"default"},
 			},
 		},
-	}
+	})
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "mybin",
 		Goos:   "linux",
@@ -605,18 +624,14 @@ func TestRunPipeInvalidContentsSourceTemplate(t *testing.T) {
 }
 
 func TestNoBuildsFound(t *testing.T) {
-	ctx := &context.Context{
-		Parallelism: runtime.NumCPU(),
-		Artifacts:   artifact.New(),
-		Config: config.Project{
-			NFPMs: []config.NFPM{
-				{
-					Formats: []string{"deb"},
-					Builds:  []string{"nope"},
-				},
+	ctx := testctx.NewWithCfg(config.Project{
+		NFPMs: []config.NFPM{
+			{
+				Formats: []string{"deb"},
+				Builds:  []string{"nope"},
 			},
 		},
-	}
+	})
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "mybin",
 		Goos:   "linux",
@@ -634,7 +649,7 @@ func TestCreateFileDoesntExist(t *testing.T) {
 	dist := filepath.Join(folder, "dist")
 	require.NoError(t, os.Mkdir(dist, 0o755))
 	require.NoError(t, os.Mkdir(filepath.Join(dist, "mybin"), 0o755))
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist:        dist,
 		ProjectName: "asd",
 		NFPMs: []config.NFPM{
@@ -652,11 +667,7 @@ func TestCreateFileDoesntExist(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.2.3"
-	ctx.Git = context.GitInfo{
-		CurrentTag: "v1.2.3",
-	}
+	}, testctx.WithVersion("1.2.3"), testctx.WithCurrentTag("v1.2.3"))
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "mybin",
 		Path:   filepath.Join(dist, "mybin", "mybin"),
@@ -675,7 +686,7 @@ func TestInvalidConfig(t *testing.T) {
 	dist := filepath.Join(folder, "dist")
 	require.NoError(t, os.Mkdir(dist, 0o755))
 	require.NoError(t, os.Mkdir(filepath.Join(dist, "mybin"), 0o755))
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Dist: dist,
 		NFPMs: []config.NFPM{
 			{
@@ -683,9 +694,7 @@ func TestInvalidConfig(t *testing.T) {
 				Builds:  []string{"default"},
 			},
 		},
-	})
-	ctx.Git.CurrentTag = "v1.2.3"
-	ctx.Version = "1.2.3"
+	}, testctx.WithCurrentTag("v1.2.3"), testctx.WithVersion("1.2.3"))
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "mybin",
 		Path:   filepath.Join(dist, "mybin", "mybin"),
@@ -700,14 +709,12 @@ func TestInvalidConfig(t *testing.T) {
 }
 
 func TestDefault(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			ProjectName: "foobar",
-			NFPMs: []config.NFPM{
-				{},
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "foobar",
+		NFPMs: []config.NFPM{
+			{},
 		},
-	}
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "/usr/bin", ctx.Config.NFPMs[0].Bindir)
 	require.Empty(t, ctx.Config.NFPMs[0].Builds)
@@ -716,19 +723,17 @@ func TestDefault(t *testing.T) {
 }
 
 func TestDefaultSet(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			NFPMs: []config.NFPM{
-				{
-					Builds: []string{"foo"},
-					Bindir: "/bin",
-					NFPMOverridables: config.NFPMOverridables{
-						FileNameTemplate: "foo",
-					},
+	ctx := testctx.NewWithCfg(config.Project{
+		NFPMs: []config.NFPM{
+			{
+				Builds: []string{"foo"},
+				Bindir: "/bin",
+				NFPMOverridables: config.NFPMOverridables{
+					FileNameTemplate: "foo",
 				},
 			},
 		},
-	}
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, "/bin", ctx.Config.NFPMs[0].Bindir)
 	require.Equal(t, "foo", ctx.Config.NFPMs[0].FileNameTemplate)
@@ -737,23 +742,21 @@ func TestDefaultSet(t *testing.T) {
 }
 
 func TestOverrides(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			NFPMs: []config.NFPM{
-				{
-					Bindir: "/bin",
-					NFPMOverridables: config.NFPMOverridables{
-						FileNameTemplate: "foo",
-					},
-					Overrides: map[string]config.NFPMOverridables{
-						"deb": {
-							FileNameTemplate: "bar",
-						},
+	ctx := testctx.NewWithCfg(config.Project{
+		NFPMs: []config.NFPM{
+			{
+				Bindir: "/bin",
+				NFPMOverridables: config.NFPMOverridables{
+					FileNameTemplate: "foo",
+				},
+				Overrides: map[string]config.NFPMOverridables{
+					"deb": {
+						FileNameTemplate: "bar",
 					},
 				},
 			},
 		},
-	}
+	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	merged, err := mergeOverrides(ctx.Config.NFPMs[0], "deb")
 	require.NoError(t, err)
@@ -774,7 +777,7 @@ func TestDebSpecificConfig(t *testing.T) {
 		f, err := os.Create(binPath)
 		require.NoError(t, err)
 		require.NoError(t, f.Close())
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			ProjectName: "mybin",
 			Dist:        dist,
 			NFPMs: []config.NFPM{
@@ -799,9 +802,7 @@ func TestDebSpecificConfig(t *testing.T) {
 					},
 				},
 			},
-		})
-		ctx.Version = "1.0.0"
-		ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+		}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 		for _, goos := range []string{"linux", "darwin"} {
 			for _, goarch := range []string{"amd64", "386"} {
 				ctx.Artifacts.Add(&artifact.Artifact{
@@ -871,7 +872,7 @@ func TestRPMSpecificConfig(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -895,9 +896,7 @@ func TestRPMSpecificConfig(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -945,7 +944,7 @@ func TestRPMSpecificScriptsConfig(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -964,9 +963,7 @@ func TestRPMSpecificScriptsConfig(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -983,21 +980,12 @@ func TestRPMSpecificScriptsConfig(t *testing.T) {
 	}
 
 	t.Run("PreTrans script file does not exist", func(t *testing.T) {
-		require.Contains(
-			t,
-			Pipe{}.Run(ctx).Error(),
-			`open /does/not/exist_pretrans.sh: no such file or directory`,
-		)
+		require.ErrorIs(t, Pipe{}.Run(ctx), os.ErrNotExist)
 	})
 
 	t.Run("PostTrans script file does not exist", func(t *testing.T) {
 		ctx.Config.NFPMs[0].RPM.Scripts.PreTrans = "testdata/testfile.txt"
-
-		require.Contains(
-			t,
-			Pipe{}.Run(ctx).Error(),
-			`open /does/not/exist_posttrans.sh: no such file or directory`,
-		)
+		require.ErrorIs(t, Pipe{}.Run(ctx), os.ErrNotExist)
 	})
 
 	t.Run("pretrans and posttrans scriptlets set", func(t *testing.T) {
@@ -1017,7 +1005,7 @@ func TestAPKSpecificConfig(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -1042,9 +1030,7 @@ func TestAPKSpecificConfig(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -1096,7 +1082,7 @@ func TestAPKSpecificScriptsConfig(t *testing.T) {
 		PreUpgrade:  "/does/not/exist_preupgrade.sh",
 		PostUpgrade: "/does/not/exist_postupgrade.sh",
 	}
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -1119,9 +1105,7 @@ func TestAPKSpecificScriptsConfig(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -1140,23 +1124,13 @@ func TestAPKSpecificScriptsConfig(t *testing.T) {
 	t.Run("PreUpgrade script file does not exist", func(t *testing.T) {
 		ctx.Config.NFPMs[0].APK.Scripts = scripts
 		ctx.Config.NFPMs[0].APK.Scripts.PostUpgrade = "testdata/testfile.txt"
-
-		require.Contains(
-			t,
-			Pipe{}.Run(ctx).Error(),
-			`stat /does/not/exist_preupgrade.sh: no such file or directory`,
-		)
+		require.ErrorIs(t, Pipe{}.Run(ctx), os.ErrNotExist)
 	})
 
 	t.Run("PostUpgrade script file does not exist", func(t *testing.T) {
 		ctx.Config.NFPMs[0].APK.Scripts = scripts
 		ctx.Config.NFPMs[0].APK.Scripts.PreUpgrade = "testdata/testfile.txt"
-
-		require.Contains(
-			t,
-			Pipe{}.Run(ctx).Error(),
-			`stat /does/not/exist_postupgrade.sh: no such file or directory`,
-		)
+		require.ErrorIs(t, Pipe{}.Run(ctx), os.ErrNotExist)
 	})
 
 	t.Run("preupgrade and postupgrade scriptlets set", func(t *testing.T) {
@@ -1168,18 +1142,16 @@ func TestAPKSpecificScriptsConfig(t *testing.T) {
 }
 
 func TestSeveralNFPMsWithTheSameID(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			NFPMs: []config.NFPM{
-				{
-					ID: "a",
-				},
-				{
-					ID: "a",
-				},
+	ctx := testctx.NewWithCfg(config.Project{
+		NFPMs: []config.NFPM{
+			{
+				ID: "a",
+			},
+			{
+				ID: "a",
 			},
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Default(ctx), "found 2 nfpms with the ID 'a', please fix your config")
 }
 
@@ -1192,7 +1164,7 @@ func TestMeta(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -1246,9 +1218,7 @@ func TestMeta(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -1291,7 +1261,7 @@ func TestSkipSign(t *testing.T) {
 	binPath := filepath.Join(dist, "mybin", "mybin")
 	_, err = os.Create(binPath)
 	require.NoError(t, err)
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		NFPMs: []config.NFPM{
@@ -1326,9 +1296,7 @@ func TestSkipSign(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux", "darwin"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -1345,15 +1313,9 @@ func TestSkipSign(t *testing.T) {
 	}
 
 	t.Run("skip sign not set", func(t *testing.T) {
-		contains := "open /does/not/exist.gpg: no such file or directory"
-		if runtime.GOOS == "windows" {
-			contains = "open /does/not/exist.gpg: The system cannot find the path specified."
-		}
-		require.Contains(
-			t,
-			Pipe{}.Run(ctx).Error(),
-			contains,
-		)
+		// TODO: once https://github.com/goreleaser/nfpm/pull/630 is released,
+		// use require.ErrorIs() here.
+		require.Error(t, Pipe{}.Run(ctx))
 	})
 
 	t.Run("skip sign set", func(t *testing.T) {
@@ -1371,7 +1333,7 @@ func TestBinDirTemplating(t *testing.T) {
 	f, err := os.Create(binPath)
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
 		Dist:        dist,
 		Env: []string{
@@ -1398,9 +1360,7 @@ func TestBinDirTemplating(t *testing.T) {
 				},
 			},
 		},
-	})
-	ctx.Version = "1.0.0"
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	}, testctx.WithVersion("1.0.0"), testctx.WithCurrentTag("v1.0.0"))
 	for _, goos := range []string{"linux"} {
 		for _, goarch := range []string{"amd64", "386"} {
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -1430,11 +1390,11 @@ func TestBinDirTemplating(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			NFPMs: []config.NFPM{
 				{},
 			},
@@ -1443,6 +1403,49 @@ func TestSkip(t *testing.T) {
 	})
 }
 
+func TestTemplateExt(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		Dist: t.TempDir(),
+		NFPMs: []config.NFPM{
+			{
+				NFPMOverridables: config.NFPMOverridables{
+					FileNameTemplate: "a_{{ .ConventionalExtension }}_b",
+					PackageName:      "foo",
+				},
+				Meta:       true,
+				Maintainer: "foo@bar",
+				Formats:    []string{"deb", "rpm", "termux.deb", "apk", "archlinux"},
+				Builds:     []string{"default"},
+			},
+		},
+	})
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name:   "mybin",
+		Goos:   "linux",
+		Goarch: "amd64",
+		Type:   artifact.Binary,
+		Extra: map[string]interface{}{
+			artifact.ExtraID: "default",
+		},
+	})
+	require.NoError(t, Pipe{}.Run(ctx))
+
+	packages := ctx.Artifacts.Filter(artifact.ByType(artifact.LinuxPackage)).List()
+	require.Len(t, packages, 5)
+	names := make([]string, 0, 5)
+	for _, p := range packages {
+		names = append(names, p.Name)
+	}
+
+	require.ElementsMatch(t, []string{
+		"a_.apk_b.apk",
+		"a_.deb_b.deb",
+		"a_.rpm_b.rpm",
+		"a_.termux.deb_b.termux.deb",
+		"a_.pkg.tar.zst_b.pkg.tar.zst",
+	}, names)
+}
+
 func sources(contents files.Contents) []string {
 	result := make([]string, 0, len(contents))
 	for _, f := range contents {
