@@ -3,8 +3,8 @@ package publish
 import (
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -13,23 +13,19 @@ func TestDescription(t *testing.T) {
 }
 
 func TestPublish(t *testing.T) {
-	ctx := context.New(config.Project{})
-	ctx.Config.Release.Disable = true
-	ctx.TokenType = context.TokenTypeGitHub
-	for i := range ctx.Config.Dockers {
-		ctx.Config.Dockers[i].SkipPush = "true"
-	}
+	ctx := testctx.NewWithCfg(config.Project{
+		Release: config.Release{Disable: "true"},
+	}, testctx.GitHubTokenType)
 	require.NoError(t, Pipe{}.Run(ctx))
 }
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		ctx := context.New(config.Project{})
-		ctx.SkipPublish = true
+		ctx := testctx.New(testctx.SkipPublish)
 		require.True(t, Pipe{}.Skip(ctx))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		require.False(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.False(t, Pipe{}.Skip(testctx.New()))
 	})
 }
